@@ -1,10 +1,15 @@
 mod binder;
 pub mod code_actions;
 pub mod column_name;
+pub mod document_symbols;
 pub mod expand_selection;
+pub mod find_references;
 mod generated;
 pub mod goto_definition;
+pub mod hover;
+pub mod inlay_hints;
 mod offsets;
+mod quote;
 mod resolve;
 mod scope;
 mod symbols;
