@@ -146,12 +146,18 @@ pub(crate) fn constraint_missing_not_valid(ctx: &mut Linter, parse: &Parse<Sourc
 
 #[cfg(test)]
 mod test {
-    use insta::assert_debug_snapshot;
+    use insta::assert_snapshot;
 
-    use crate::{
-        Rule,
-        test_utils::{lint, lint_with_assume_in_transaction},
-    };
+    use crate::test_utils::{lint_errors, lint_ok};
+    use crate::{LinterSettings, Rule};
+
+    fn lint_ok_with(sql: &str, settings: LinterSettings) {
+        crate::test_utils::lint_ok_with(sql, settings, Rule::ConstraintMissingNotValid);
+    }
+
+    fn lint_errors_with(sql: &str, settings: LinterSettings) -> String {
+        crate::test_utils::lint_errors_with(sql, settings, Rule::ConstraintMissingNotValid)
+    }
 
     #[test]
     fn not_valid_validate_transaction_err() {
@@ -161,9 +167,7 @@ ALTER TABLE "app_email" ADD CONSTRAINT "fk_user" FOREIGN KEY (user_id) REFERENCE
 ALTER TABLE "app_email" VALIDATE CONSTRAINT "fk_user";
 COMMIT;
         "#;
-        let errors = lint(sql, Rule::ConstraintMissingNotValid);
-        assert_ne!(errors.len(), 0);
-        assert_debug_snapshot!(errors);
+        assert_snapshot!(lint_errors(sql, Rule::ConstraintMissingNotValid));
     }
 
     #[test]
@@ -172,9 +176,13 @@ COMMIT;
 ALTER TABLE "app_email" ADD CONSTRAINT "fk_user" FOREIGN KEY (user_id) REFERENCES "app_user" (id) NOT VALID;
 ALTER TABLE "app_email" VALIDATE CONSTRAINT "fk_user";
         "#;
-        let errors = lint_with_assume_in_transaction(sql, Rule::ConstraintMissingNotValid);
-        assert_ne!(errors.len(), 0);
-        assert_debug_snapshot!(errors);
+        assert_snapshot!(lint_errors_with(
+            sql,
+            LinterSettings {
+                assume_in_transaction: true,
+                ..Default::default()
+            },
+        ));
     }
 
     #[test]
@@ -184,9 +192,13 @@ ALTER TABLE "app_email" ADD CONSTRAINT "fk_user" FOREIGN KEY (user_id) REFERENCE
 ALTER TABLE "app_email" VALIDATE CONSTRAINT "fk_user";
 COMMIT;
         "#;
-        let errors = lint_with_assume_in_transaction(sql, Rule::ConstraintMissingNotValid);
-        assert_ne!(errors.len(), 0);
-        assert_debug_snapshot!(errors);
+        assert_snapshot!(lint_errors_with(
+            sql,
+            LinterSettings {
+                assume_in_transaction: true,
+                ..Default::default()
+            },
+        ));
     }
 
     #[test]
@@ -195,9 +207,7 @@ COMMIT;
 -- instead of
 ALTER TABLE distributors ADD CONSTRAINT distfk FOREIGN KEY (address) REFERENCES addresses (address);
         "#;
-        let errors = lint(sql, Rule::ConstraintMissingNotValid);
-        assert_ne!(errors.len(), 0);
-        assert_debug_snapshot!(errors);
+        assert_snapshot!(lint_errors(sql, Rule::ConstraintMissingNotValid));
     }
 
     #[test]
@@ -207,8 +217,7 @@ ALTER TABLE distributors ADD CONSTRAINT distfk FOREIGN KEY (address) REFERENCES
 ALTER TABLE distributors ADD CONSTRAINT distfk FOREIGN KEY (address) REFERENCES addresses (address) NOT VALID;
 ALTER TABLE distributors VALIDATE CONSTRAINT distfk;
         "#;
-        let errors = lint(sql, Rule::ConstraintMissingNotValid);
-        assert_eq!(errors.len(), 0);
+        lint_ok(sql, Rule::ConstraintMissingNotValid);
     }
 
     #[test]
@@ -216,8 +225,7 @@ ALTER TABLE distributors VALIDATE CONSTRAINT distfk;
         let sql = r#"
 ALTER TABLE account ADD CONSTRAINT account_pk PRIMARY KEY USING INDEX account_pk_idx;
         "#;
-        let errors = lint(sql, Rule::ConstraintMissingNotValid);
-        assert_eq!(errors.len(), 0);
+        lint_ok(sql, Rule::ConstraintMissingNotValid);
     }
 
     #[test]
@@ -226,9 +234,13 @@ ALTER TABLE account ADD CONSTRAINT account_pk PRIMARY KEY USING INDEX account_pk
 -- instead of
 ALTER TABLE "accounts" ADD CONSTRAINT "positive_balance" CHECK ("balance" >= 0);
         "#;
-        let errors = lint_with_assume_in_transaction(sql, Rule::ConstraintMissingNotValid);
-        assert_ne!(errors.len(), 0);
-        assert_debug_snapshot!(errors);
+        assert_snapshot!(lint_errors_with(
+            sql,
+            LinterSettings {
+                assume_in_transaction: true,
+                ..Default::default()
+            },
+        ));
     }
 
     #[test]
@@ -238,8 +250,7 @@ ALTER TABLE "accounts" ADD CONSTRAINT "positive_balance" CHECK ("balance" >= 0);
 ALTER TABLE "accounts" ADD CONSTRAINT "positive_balance" CHECK ("balance" >= 0) NOT VALID;
 ALTER TABLE accounts VALIDATE CONSTRAINT positive_balance;
         "#;
-        let errors = lint(sql, Rule::ConstraintMissingNotValid);
-        assert_eq!(errors.len(), 0);
+        lint_ok(sql, Rule::ConstraintMissingNotValid);
     }
 
     #[test]
@@ -253,8 +264,7 @@ CREATE TABLE "core_foo" (
 ALTER TABLE "core_foo" ADD CONSTRAINT "age_restriction" CHECK ("age" >= 25);
 COMMIT;
         "#;
-        let errors = lint(sql, Rule::ConstraintMissingNotValid);
-        assert_eq!(errors.len(), 0);
+        lint_ok(sql, Rule::ConstraintMissingNotValid);
     }
 
     #[test]
@@ -266,8 +276,13 @@ CREATE TABLE "core_foo" (
 );
 ALTER TABLE "core_foo" ADD CONSTRAINT "age_restriction" CHECK ("age" >= 25);
         "#;
-        let errors = lint_with_assume_in_transaction(sql, Rule::ConstraintMissingNotValid);
-        assert_eq!(errors.len(), 0);
+        lint_ok_with(
+            sql,
+            LinterSettings {
+                assume_in_transaction: true,
+                ..Default::default()
+            },
+        );
     }
 
     #[test]
@@ -279,8 +294,13 @@ CREATE TABLE "core_foo" (
 );
 ALTER TABLE "core_foo" ADD CONSTRAINT "age_restriction" CHECK ("age" >= 25);
         "#;
-        let errors = lint_with_assume_in_transaction(sql, Rule::ConstraintMissingNotValid);
-        assert_eq!(errors.len(), 0);
+        lint_ok_with(
+            sql,
+            LinterSettings {
+                assume_in_transaction: true,
+                ..Default::default()
+            },
+        );
     }
 
     #[test]
@@ -288,7 +308,6 @@ ALTER TABLE "core_foo" ADD CONSTRAINT "age_restriction" CHECK ("age" >= 25);
         let sql = r#"
 ALTER TABLE "app_email" ADD CONSTRAINT "email_uniq" UNIQUE USING INDEX "email_idx";
         "#;
-        let errors = lint(sql, Rule::ConstraintMissingNotValid);
-        assert_eq!(errors.len(), 0);
+        lint_ok(sql, Rule::ConstraintMissingNotValid);
     }
 }
