@@ -46,6 +46,21 @@ create unlogged table t (
   )
 );
 
+create table t partition of u
+    -- missing some commas
+    for values from ('2024-01-01'  1) to ('2024-04-01'  5);
+
+create table t partition of u
+    -- missing some commas
+    for values in (1  2  3);
+
+-- exclude missing a comma
+create table t (
+  a int,
+  b text,
+  exclude using btree ( a with buzz.> b with <) 
+);
+
 create table z (
   a int
 )
