@@ -6,20 +6,29 @@ use lsp_types::{
     CodeAction, CodeActionKind, CodeActionOptions, CodeActionOrCommand, CodeActionParams,
     CodeActionProviderCapability, CodeActionResponse, Command, Diagnostic,
     DidChangeTextDocumentParams, DidCloseTextDocumentParams, DidOpenTextDocumentParams,
-    GotoDefinitionParams, GotoDefinitionResponse, InitializeParams, Location, OneOf,
-    PublishDiagnosticsParams, SelectionRangeParams, SelectionRangeProviderCapability,
-    ServerCapabilities, TextDocumentSyncCapability, TextDocumentSyncKind, Url,
-    WorkDoneProgressOptions, WorkspaceEdit,
+    DocumentSymbol, DocumentSymbolParams, GotoDefinitionParams, GotoDefinitionResponse, Hover,
+    HoverContents, HoverParams, HoverProviderCapability, InitializeParams, InlayHint,
+    InlayHintKind, InlayHintLabel, InlayHintLabelPart, InlayHintParams, LanguageString, Location,
+    MarkedString, OneOf, PublishDiagnosticsParams, ReferenceParams, SelectionRangeParams,
+    SelectionRangeProviderCapability, ServerCapabilities, SymbolKind, TextDocumentSyncCapability,
+    TextDocumentSyncKind, Url, WorkDoneProgressOptions, WorkspaceEdit,
     notification::{
         DidChangeTextDocument, DidCloseTextDocument, DidOpenTextDocument, Notification as _,
         PublishDiagnostics,
     },
-    request::{CodeActionRequest, GotoDefinition, Request, SelectionRangeRequest},
+    request::{
+        CodeActionRequest, DocumentSymbolRequest, GotoDefinition, HoverRequest, InlayHintRequest,
+        References, Request, SelectionRangeRequest,
+    },
 };
 use rowan::TextRange;
 use squawk_ide::code_actions::code_actions;
+use squawk_ide::document_symbols::{DocumentSymbolKind, document_symbols};
+use squawk_ide::find_references::find_references;
 use squawk_ide::goto_definition::goto_definition;
-use squawk_syntax::{Parse, SourceFile};
+use squawk_ide::hover::hover;
+use squawk_ide::inlay_hints::inlay_hints;
+use squawk_syntax::SourceFile;
 use std::collections::HashMap;
 
 use diagnostic::DIAGNOSTIC_NAME;
@@ -55,7 +64,11 @@ pub fn run() -> Result<()> {
             resolve_provider: None,
         })),
         selection_range_provider: Some(SelectionRangeProviderCapability::Simple(true)),
+        references_provider: Some(OneOf::Left(true)),
         definition_provider: Some(OneOf::Left(true)),
+        hover_provider: Some(HoverProviderCapability::Simple(true)),
+        inlay_hint_provider: Some(OneOf::Left(true)),
+        document_symbol_provider: Some(OneOf::Left(true)),
         ..Default::default()
     })
     .unwrap();
@@ -96,18 +109,30 @@ fn main_loop(connection: Connection, params: serde_json::Value) -> Result<()> {
                     GotoDefinition::METHOD => {
                         handle_goto_definition(&connection, req, &documents)?;
                     }
+                    HoverRequest::METHOD => {
+                        handle_hover(&connection, req, &documents)?;
+                    }
                     CodeActionRequest::METHOD => {
                         handle_code_action(&connection, req, &documents)?;
                     }
                     SelectionRangeRequest::METHOD => {
                         handle_selection_range(&connection, req, &documents)?;
                     }
+                    InlayHintRequest::METHOD => {
+                        handle_inlay_hints(&connection, req, &documents)?;
+                    }
+                    DocumentSymbolRequest::METHOD => {
+                        handle_document_symbol(&connection, req, &documents)?;
+                    }
                     "squawk/syntaxTree" => {
                         handle_syntax_tree(&connection, req, &documents)?;
                     }
                     "squawk/tokens" => {
                         handle_tokens(&connection, req, &documents)?;
                     }
+                    References::METHOD => {
+                        handle_references(&connection, req, &documents)?;
+                    }
                     _ => {
                         info!("Ignoring unhandled request: {}", req.method);
                     }
@@ -148,7 +173,7 @@ fn handle_goto_definition(
     let position = params.text_document_position_params.position;
 
     let content = documents.get(&uri).map_or("", |doc| &doc.content);
-    let parse: Parse<SourceFile> = SourceFile::parse(content);
+    let parse = SourceFile::parse(content);
     let file = parse.tree();
     let line_index = LineIndex::new(content);
     let offset = lsp_utils::offset(&line_index, position).unwrap();
@@ -179,6 +204,167 @@ fn handle_goto_definition(
     Ok(())
 }
 
+fn handle_hover(
+    connection: &Connection,
+    req: lsp_server::Request,
+    documents: &HashMap<Url, DocumentState>,
+) -> Result<()> {
+    let params: HoverParams = serde_json::from_value(req.params)?;
+    let uri = params.text_document_position_params.text_document.uri;
+    let position = params.text_document_position_params.position;
+
+    let content = documents.get(&uri).map_or("", |doc| &doc.content);
+    let parse = SourceFile::parse(content);
+    let file = parse.tree();
+    let line_index = LineIndex::new(content);
+    let offset = lsp_utils::offset(&line_index, position).unwrap();
+
+    let type_info = hover(&file, offset);
+
+    let result = type_info.map(|type_str| Hover {
+        contents: HoverContents::Scalar(MarkedString::LanguageString(LanguageString {
+            language: "sql".to_string(),
+            value: type_str,
+        })),
+        range: None,
+    });
+
+    let resp = Response {
+        id: req.id,
+        result: Some(serde_json::to_value(&result).unwrap()),
+        error: None,
+    };
+
+    connection.sender.send(Message::Response(resp))?;
+    Ok(())
+}
+
+fn handle_inlay_hints(
+    connection: &Connection,
+    req: lsp_server::Request,
+    documents: &HashMap<Url, DocumentState>,
+) -> Result<()> {
+    let params: InlayHintParams = serde_json::from_value(req.params)?;
+    let uri = params.text_document.uri;
+
+    let content = documents.get(&uri).map_or("", |doc| &doc.content);
+    let parse = SourceFile::parse(content);
+    let file = parse.tree();
+    let line_index = LineIndex::new(content);
+
+    let hints = inlay_hints(&file);
+
+    let lsp_hints: Vec<InlayHint> = hints
+        .into_iter()
+        .map(|hint| {
+            let line_col = line_index.line_col(hint.position);
+            let position = lsp_types::Position::new(line_col.line, line_col.col);
+            let kind = match hint.kind {
+                squawk_ide::inlay_hints::InlayHintKind::Type => InlayHintKind::TYPE,
+                squawk_ide::inlay_hints::InlayHintKind::Parameter => InlayHintKind::PARAMETER,
+            };
+
+            let label = if let Some(target_range) = hint.target {
+                InlayHintLabel::LabelParts(vec![InlayHintLabelPart {
+                    value: hint.label,
+                    location: Some(Location {
+                        uri: uri.clone(),
+                        range: lsp_utils::range(&line_index, target_range),
+                    }),
+                    tooltip: None,
+                    command: None,
+                }])
+            } else {
+                InlayHintLabel::String(hint.label)
+            };
+
+            InlayHint {
+                position,
+                label,
+                kind: Some(kind),
+                text_edits: None,
+                tooltip: None,
+                padding_left: None,
+                padding_right: None,
+                data: None,
+            }
+        })
+        .collect();
+
+    let resp = Response {
+        id: req.id,
+        result: Some(serde_json::to_value(&lsp_hints).unwrap()),
+        error: None,
+    };
+
+    connection.sender.send(Message::Response(resp))?;
+    Ok(())
+}
+
+fn handle_document_symbol(
+    connection: &Connection,
+    req: lsp_server::Request,
+    documents: &HashMap<Url, DocumentState>,
+) -> Result<()> {
+    let params: DocumentSymbolParams = serde_json::from_value(req.params)?;
+    let uri = params.text_document.uri;
+
+    let content = documents.get(&uri).map_or("", |doc| &doc.content);
+    let parse = SourceFile::parse(content);
+    let file = parse.tree();
+    let line_index = LineIndex::new(content);
+
+    let symbols = document_symbols(&file);
+
+    fn convert_symbol(
+        sym: squawk_ide::document_symbols::DocumentSymbol,
+        line_index: &LineIndex,
+    ) -> DocumentSymbol {
+        let range = lsp_utils::range(line_index, sym.full_range);
+        let selection_range = lsp_utils::range(line_index, sym.focus_range);
+
+        let children = sym
+            .children
+            .into_iter()
+            .map(|child| convert_symbol(child, line_index))
+            .collect::<Vec<_>>();
+
+        let children = (!children.is_empty()).then_some(children);
+
+        DocumentSymbol {
+            name: sym.name,
+            detail: sym.detail,
+            kind: match sym.kind {
+                DocumentSymbolKind::Table => SymbolKind::STRUCT,
+                DocumentSymbolKind::Function => SymbolKind::FUNCTION,
+                DocumentSymbolKind::Type => SymbolKind::CLASS,
+                DocumentSymbolKind::Column => SymbolKind::FIELD,
+                DocumentSymbolKind::Variant => SymbolKind::ENUM_MEMBER,
+            },
+            tags: None,
+            range,
+            selection_range,
+            children,
+            #[allow(deprecated)]
+            deprecated: None,
+        }
+    }
+
+    let lsp_symbols: Vec<DocumentSymbol> = symbols
+        .into_iter()
+        .map(|sym| convert_symbol(sym, &line_index))
+        .collect();
+
+    let resp = Response {
+        id: req.id,
+        result: Some(serde_json::to_value(&lsp_symbols).unwrap()),
+        error: None,
+    };
+
+    connection.sender.send(Message::Response(resp))?;
+    Ok(())
+}
+
 fn handle_selection_range(
     connection: &Connection,
     req: lsp_server::Request,
@@ -188,7 +374,7 @@ fn handle_selection_range(
     let uri = params.text_document.uri;
 
     let content = documents.get(&uri).map_or("", |doc| &doc.content);
-    let parse: Parse<SourceFile> = SourceFile::parse(content);
+    let parse = SourceFile::parse(content);
     let root = parse.syntax_node();
     let line_index = LineIndex::new(content);
 
@@ -236,6 +422,43 @@ fn handle_selection_range(
     Ok(())
 }
 
+fn handle_references(
+    connection: &Connection,
+    req: lsp_server::Request,
+    documents: &HashMap<Url, DocumentState>,
+) -> Result<()> {
+    let params: ReferenceParams = serde_json::from_value(req.params)?;
+    let uri = params.text_document_position.text_document.uri;
+    let position = params.text_document_position.position;
+
+    let content = documents.get(&uri).map_or("", |doc| &doc.content);
+    let parse = SourceFile::parse(content);
+    let file = parse.tree();
+    let line_index = LineIndex::new(content);
+    let offset = lsp_utils::offset(&line_index, position).unwrap();
+
+    let ranges = find_references(&file, offset);
+    let include_declaration = params.context.include_declaration;
+
+    let locations: Vec<Location> = ranges
+        .into_iter()
+        .filter(|range| include_declaration || !range.contains(offset))
+        .map(|range| Location {
+            uri: uri.clone(),
+            range: lsp_utils::range(&line_index, range),
+        })
+        .collect();
+
+    let resp = Response {
+        id: req.id,
+        result: Some(serde_json::to_value(&locations).unwrap()),
+        error: None,
+    };
+
+    connection.sender.send(Message::Response(resp))?;
+    Ok(())
+}
+
 fn handle_code_action(
     connection: &Connection,
     req: lsp_server::Request,
@@ -247,7 +470,7 @@ fn handle_code_action(
     let mut actions: CodeActionResponse = Vec::new();
 
     let content = documents.get(&uri).map_or("", |doc| &doc.content);
-    let parse: Parse<SourceFile> = SourceFile::parse(content);
+    let parse = SourceFile::parse(content);
     let file = parse.tree();
     let line_index = LineIndex::new(content);
     let offset = lsp_utils::offset(&line_index, params.range.start).unwrap();
@@ -484,7 +707,7 @@ fn handle_syntax_tree(
 
     let content = documents.get(&uri).map_or("", |doc| &doc.content);
 
-    let parse: Parse<SourceFile> = SourceFile::parse(content);
+    let parse = SourceFile::parse(content);
     let syntax_tree = format!("{:#?}", parse.syntax_node());
 
     let resp = Response {
