@@ -54,6 +54,8 @@ pub use self::{
         // HasVisibility,
         // HasGenericParams, HasLoopBody,
         HasName,
+        HasParamList,
+        NameLike,
     },
 };
 
