@@ -9,12 +9,20 @@ pub trait HasName: AstNode {
     }
 }
 
+pub trait NameLike: AstNode {}
+
 pub trait HasArgList: AstNode {
     fn arg_list(&self) -> Option<ast::ArgList> {
         support::child(self.syntax())
     }
 }
 
+pub trait HasParamList: AstNode {
+    fn param_list(&self) -> Option<ast::ParamList> {
+        support::child(self.syntax())
+    }
+}
+
 pub trait HasIfExists: AstNode {
     fn if_exists(&self) -> Option<ast::IfExists> {
         support::child(self.syntax())
